| Title: | Setup a project in the tflow style for using the targets package |
|---|---|
| Description: | Has a function that sets up an R workflow in the dflow style, using targets. |
| Authors: | Miles McBain [aut, cre], Shir Dekel [ctb], Noam Ross [aut] (ORCID: <https://orcid.org/0000-0002-2136-0000>), Robert M Flight [ctb] (ORCID: <https://orcid.org/0000-0001-8141-7788>) |
| Maintainer: | Miles McBain <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.4.1 |
| Built: | 2026-05-18 07:18:11 UTC |
| Source: | https://github.com/milesmcbain/tflow |
Generate a target for a Quarto file
qmd_target(target_name)qmd_target(target_name)
target_name |
of a target to generate qmd target for. |
target text to the console.
Robert M Flight
Generate a target for an R markdown file
rmd_target(target_name)rmd_target(target_name)
target_name |
of a target to generate rmd target for. |
target text to the console.
Miles McBain
Use a starter .gitignore
use_gitignore()use_gitignore()
Drop a starter .gitignore in the current working directory, including ignores for targets and capsule (renv).
nothing, creates a file.
Miles McBain
Create a Quarto file and generate target definition code.
use_qmd(target_name)use_qmd(target_name)
target_name |
a name for target and the generated quarto document. |
The generated document defaults to the "./doc" folder. This can be overridden with option 'tflow.report_dir'.
the path of the file created. (invisibly)
Robert M Flight
Create an RMarkdown file and generate target definition code.
use_rmd(target_name)use_rmd(target_name)
target_name |
a name for target and the generated R markdown document. |
The generated document defaults to the "./doc" folder. This can be overridden with option 'tflow.report_dir'.
the path of the file created. (invisibly)
Miles McBain
Setup a tflow project
use_tflow()use_tflow()
Creates files and directories according to the tflow template.
Nothing. Modifies your workspace.